======================================
Installing Ironic Python Agent Builder
======================================

Download the ``ironic-python-agent-builder`` archive from
`tarballs.openstack.org`_, install it from your distribution's repositories
or use pip::

    pip install --user diskimage-builder ironic-python-agent-builder

In RDO_, the package is available since Train under a slightly different name::

    sudo yum install -y openstack-ironic-python-agent-builder

.. _tarballs.openstack.org: https://tarballs.openstack.org/ironic-python-agent-builder/
.. _RDO: https://rdoproject.org
